@@ -146,9 +146,8 @@ class CoreDatabase:
         list
             Record-like dict list when resp specified
         """
-
         # auto pack to tuple if needed
-        if not (isinstance(vals, dict) or isinstance(vals, tuple)):
+        if vals and not (isinstance(vals, dict) or isinstance(vals, tuple)):
             vals = vals,
 
         fetched, cols = [], []
